<?php
/**
* @package  PayPlans
* @copyright Copyright (C) Stack Ideas Sdn Bhd. All rights reserved.
* @license  GNU/GPL, see LICENSE.php
* PayPlans is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

ES::import('admin:/includes/apps/apps');

class SocialUserAppPayPlans extends SocialAppItem
{
	/**
	 * Function being triggered from EasySocial when processing GDPR data.
	 *
	 * @since	1.0.1
	 * @access	public
	 */
	public function onExportGdpr(SocialGdprSection &$section, &$esParams)
	{
		if (!$this->exists()) {
			return 1;
		}

		$esUser = $section->user;
		$esLib = ES::gdpr();

		$ppSection = $esLib->createSection($section->user, 'payplans', JText::_('APP_USER_PAYPLANS_GDPR_SECTION'), false);

		$items = $this->getAvailableAdapters();

		$user = PP::user($esUser->id);
		$params = PP::registry();
		$gdpr = PP::gdpr();

		$states = [];

		// Ensure the class is not exists yet before include. #1649
		if (!class_exists('SocialGdprItem')) {
			$file = __DIR__ . '/gdpr/item.php';

			require_once($file);
		}

		foreach ($items as $type) {
			$file = PP_LIB . '/gdpr/types/' . $type . '.php';
			require_once($file);

			$className = 'PayplansGdpr' . ucfirst($type);
			$adapter = new $className($user, $params);

			$esAdapter = new SocialGdprItem($section->user, $esParams);
			$adapter->onEasySocialGdprExport($ppSection, $esAdapter, $esParams);

			// Determine if the process is completed
			$states[] = $esAdapter->getParams('complete');
		}

		if (in_array(false, $states)) {
			return 0;
		}

		return 1;
	}

	/**
	 * Retrieves a list of built-in gdpr adapters available
	 *
	 * @since	1.0.1
	 * @access	public
	 */
	public function getAvailableAdapters()
	{
		static $adapters = null;

		if (is_null($adapters)) {
			$files = JFolder::files(PP_LIB . '/gdpr/types', '.php$', false, false, ['.svn', 'CVS', '.DS_Store', '__MACOSX', 'abstract.php']);

			foreach ($files as $file) {
				$adapters[] = str_ireplace('.php', '', $file);
			}
		}

		return $adapters;
	}

	/**
	 * Determines if PayPlans exists
	 *
	 * @since	1.0.1
	 * @access	public
	 */
	public function exists()
	{
		$file = JPATH_ADMINISTRATOR . '/components/com_payplans/includes/payplans.php';

		if (!JFile::exists($file)) {
			return false;
		}

		require_once($file);

		return true;
	}
}